==> blesta-5.10.2.zip: blesta/language/de_de/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Schwarze Liste';
$lang['Navigation.getsearchoptions.packages'] = 'Paket-Suche';
$lang['Navigation.getsearchoptions.services'] = 'Dienst Suche';
$lang['Navigation.getsearchoptions.transactions'] = 'Transaktionssuche';
$lang['Navigation.getsearchoptions.invoices'] = 'Suche nach Rechnungen';
$lang['Navigation.getsearchoptions.clients'] = 'Suche nach Kunden';
$lang['Navigation.getsearchoptions.smart'] = 'Intelligente Suche';
$lang['Navigation.getsystem.nav_marketplace'] = 'Marktplatz';
$lang['Navigation.getsystem.nav_help_about'] = 'Über Blesta';
$lang['Navigation.getsystem.nav_help_notes'] = 'Anmerkungen zur Veröffentlichung';
$lang['Navigation.getsystem.nav_help_index'] = 'Ressourcen';
$lang['Navigation.getsystem.nav_help'] = 'Hilfe';
$lang['Navigation.getsystem.nav_upgrade'] = 'Upgrade-Optionen';
$lang['Navigation.getsystem.nav_api'] = 'API-Zugang';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Personalgruppen';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Personal verwalten';
$lang['Navigation.getsystem.nav_staff'] = 'Personal';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Abrufbar';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Sicheres FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Sicherung';
$lang['Navigation.getsystem.nav_companies'] = 'Unternehmen';
$lang['Navigation.getsystem.nav_automation'] = 'Automatisierung';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Zahlungsarten';
$lang['Navigation.getsystem.nav_general_license'] = 'Lizenzschlüssel';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Wartung';
$lang['Navigation.getsystem.nav_general_geoip'] = 'GeoIP-Einstellungen';
$lang['Navigation.getsystem.nav_general_basic'] = 'Grundlegende Einrichtung';
$lang['Navigation.getsystem.nav_general'] = 'Allgemein';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Feed-Einstellungen';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Allgemein';
$lang['Navigation.getcompany.nav_feeds'] = 'Dateneinspeisungen';
$lang['Navigation.getcompany.nav_groups'] = 'Kundengruppen';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugins';
$lang['Navigation.getcompany.nav_currency_active'] = 'Aktive Währungen';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Währung einrichten';
$lang['Navigation.getcompany.nav_currencies'] = 'Währungen';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Erforderliche Kundenfelder';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Kundenspezifische Felder';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Allgemeine Client-Einstellungen';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Optionen für Kunden';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Unterschriften';
$lang['Navigation.getcompany.nav_emails_templates'] = 'E-Mail-Vorlagen';
$lang['Navigation.getcompany.nav_emails_mail'] = 'E-Mail-Einstellungen';
$lang['Navigation.getcompany.nav_emails'] = 'E-Mails';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Steuerliche Vorschriften';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Grundlegende Steuereinstellungen';
$lang['Navigation.getcompany.nav_taxes'] = 'Steuern';
$lang['Navigation.getcompany.nav_gateways'] = 'Zahlungs-Gateways';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Vorlagen für Nachrichten';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Messenger-Konfiguration';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Boten';
$lang['Navigation.getcompany.nav_messengers'] = 'Boten';
$lang['Navigation.getcompany.nav_modules'] = 'Module';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Akzeptierte Zahlungsarten';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Gutscheine';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Notizen';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Säumniszuschläge';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Lieferung von Rechnungen';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Anpassung von Rechnungen';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Optionen für Rechnungen und Entgelte';
$lang['Navigation.getcompany.nav_billing'] = 'Abrechnung/Zahlung';
$lang['Navigation.getcompany.nav_automation'] = 'Automatisierung';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Anpassen';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Aktionen';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigation';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Layout';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Vorlage';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Themen';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Aussehen und Gefühl';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Menschliche Verifizierung';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Intelligente Suche';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Marketing';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Kontaktarten';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Verschlüsselung';
$lang['Navigation.getcompany.nav_general_international'] = 'Internationalisierung';
$lang['Navigation.getcompany.nav_general_localization'] = 'Lokalisierung';
$lang['Navigation.getcompany.nav_general'] = 'Allgemein';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Startseite';
$lang['Navigation.getprimaryclient.nav_return'] = 'Zurück zum Dashboard';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Kontakt hinzufügen';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Kontakte';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Zahlungskonto hinzufügen';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Zahlungskonten';
$lang['Navigation.getprimaryclient.nav_services'] = 'Dienstleistungen';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Dashboard';
$lang['Navigation.getprimary.nav_settings_system'] = 'System';
$lang['Navigation.getprimary.nav_settings_company'] = 'Unternehmen';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Warteschlange für die Verlängerung';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Versorgungsunternehmen';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Währung umrechnen';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Protokolle';
$lang['Navigation.getprimary.nav_tools'] = 'Werkzeuge';
$lang['Navigation.getprimary.nav_package_options'] = 'Konfigurierbare Optionen';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Paketgruppen';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Pakete durchsuchen';
$lang['Navigation.getprimary.nav_packages'] = 'Pakete';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Stapel';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Druck-Warteschlange';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Berichte';
$lang['Navigation.getprimary.nav_billing_services'] = 'Dienstleistungen';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Transaktionen';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Kostenvoranschläge';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Rechnungen';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Übersicht';
$lang['Navigation.getprimary.nav_billing'] = 'Rechnungsstellung';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Kunden durchsuchen';
$lang['Navigation.getprimary.nav_clients'] = 'Kunden';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Dashboard';
$lang['Navigation.getprimary.nav_home'] = 'Startseite';
$lang['Navigation.!error.parent_id.valid'] = 'Ungültige ID des übergeordneten Navigationselements';
$lang['Navigation.!error.order.valid'] = 'Der Auftragsindex muss ein numerischer Wert sein';
$lang['Navigation.!error.action_id.valid'] = 'Ungültige Aktions-ID';

==> blesta-5.11.4.zip: blesta/language/de_de/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Schwarze Liste';
$lang['Navigation.getsearchoptions.packages'] = 'Paket-Suche';
$lang['Navigation.getsearchoptions.services'] = 'Dienst Suche';
$lang['Navigation.getsearchoptions.transactions'] = 'Transaktionssuche';
$lang['Navigation.getsearchoptions.invoices'] = 'Suche nach Rechnungen';
$lang['Navigation.getsearchoptions.clients'] = 'Suche nach Kunden';
$lang['Navigation.getsearchoptions.smart'] = 'Intelligente Suche';
$lang['Navigation.getsystem.nav_marketplace'] = 'Marktplatz';
$lang['Navigation.getsystem.nav_help_about'] = 'Über Blesta';
$lang['Navigation.getsystem.nav_help_notes'] = 'Anmerkungen zur Veröffentlichung';
$lang['Navigation.getsystem.nav_help_index'] = 'Ressourcen';
$lang['Navigation.getsystem.nav_help'] = 'Hilfe';
$lang['Navigation.getsystem.nav_upgrade'] = 'Upgrade-Optionen';
$lang['Navigation.getsystem.nav_api'] = 'API-Zugang';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Personalgruppen';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Personal verwalten';
$lang['Navigation.getsystem.nav_staff'] = 'Personal';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_backup_index'] = 'Abrufbar';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Sicheres FTP';
$lang['Navigation.getsystem.nav_backup'] = 'Sicherung';
$lang['Navigation.getsystem.nav_companies'] = 'Unternehmen';
$lang['Navigation.getsystem.nav_automation'] = 'Automatisierung';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Zahlungsarten';
$lang['Navigation.getsystem.nav_general_license'] = 'Lizenzschlüssel';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Wartung';
$lang['Navigation.getsystem.nav_general_geoip'] = 'GeoIP-Einstellungen';
$lang['Navigation.getsystem.nav_general_basic'] = 'Grundlegende Einrichtung';
$lang['Navigation.getsystem.nav_general'] = 'Allgemein';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Feed-Einstellungen';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Allgemein';
$lang['Navigation.getcompany.nav_feeds'] = 'Dateneinspeisungen';
$lang['Navigation.getcompany.nav_groups'] = 'Kundengruppen';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugins';
$lang['Navigation.getcompany.nav_currency_active'] = 'Aktive Währungen';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Währung einrichten';
$lang['Navigation.getcompany.nav_currencies'] = 'Währungen';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Erforderliche Kundenfelder';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Kundenspezifische Felder';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Allgemeine Client-Einstellungen';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Optionen für Kunden';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Unterschriften';
$lang['Navigation.getcompany.nav_emails_templates'] = 'E-Mail-Vorlagen';
$lang['Navigation.getcompany.nav_emails_mail'] = 'E-Mail-Einstellungen';
$lang['Navigation.getcompany.nav_emails'] = 'E-Mails';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Steuerliche Vorschriften';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Grundlegende Steuereinstellungen';
$lang['Navigation.getcompany.nav_taxes'] = 'Steuern';
$lang['Navigation.getcompany.nav_gateways'] = 'Zahlungs-Gateways';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Vorlagen für Nachrichten';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Messenger-Konfiguration';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Boten';
$lang['Navigation.getcompany.nav_messengers'] = 'Boten';
$lang['Navigation.getcompany.nav_modules'] = 'Module';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Akzeptierte Zahlungsarten';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Gutscheine';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Notizen';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Säumniszuschläge';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Lieferung von Rechnungen';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Anpassung von Rechnungen';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Optionen für Rechnungen und Entgelte';
$lang['Navigation.getcompany.nav_billing'] = 'Abrechnung/Zahlung';
$lang['Navigation.getcompany.nav_automation'] = 'Automatisierung';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Anpassen';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Aktionen';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigation';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Layout';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Vorlage';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Themen';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Aussehen und Gefühl';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Menschliche Verifizierung';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Intelligente Suche';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Marketing';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Kontaktarten';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Verschlüsselung';
$lang['Navigation.getcompany.nav_general_international'] = 'Internationalisierung';
$lang['Navigation.getcompany.nav_general_localization'] = 'Lokalisierung';
$lang['Navigation.getcompany.nav_general'] = 'Allgemein';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Startseite';
$lang['Navigation.getprimaryclient.nav_return'] = 'Zurück zum Dashboard';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Kontakt hinzufügen';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Kontakte';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Zahlungskonto hinzufügen';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Zahlungskonten';
$lang['Navigation.getprimaryclient.nav_services'] = 'Dienstleistungen';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Dashboard';
$lang['Navigation.getprimary.nav_settings_system'] = 'System';
$lang['Navigation.getprimary.nav_settings_company'] = 'Unternehmen';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Warteschlange für die Verlängerung';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Versorgungsunternehmen';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Währung umrechnen';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Protokolle';
$lang['Navigation.getprimary.nav_tools'] = 'Werkzeuge';
$lang['Navigation.getprimary.nav_package_options'] = 'Konfigurierbare Optionen';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Paketgruppen';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Pakete durchsuchen';
$lang['Navigation.getprimary.nav_packages'] = 'Pakete';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Stapel';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Druck-Warteschlange';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Berichte';
$lang['Navigation.getprimary.nav_billing_services'] = 'Dienstleistungen';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Transaktionen';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Kostenvoranschläge';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Rechnungen';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Übersicht';
$lang['Navigation.getprimary.nav_billing'] = 'Rechnungsstellung';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Kunden durchsuchen';
$lang['Navigation.getprimary.nav_clients'] = 'Kunden';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Dashboard';
$lang['Navigation.getprimary.nav_home'] = 'Startseite';
$lang['Navigation.!error.parent_id.valid'] = 'Ungültige ID des übergeordneten Navigationselements';
$lang['Navigation.!error.order.valid'] = 'Der Auftragsindex muss ein numerischer Wert sein';
$lang['Navigation.!error.action_id.valid'] = 'Ungültige Aktions-ID';
$lang['Navigation.getcompany.nav_html_templates'] = 'HTML-Vorlagen';
$lang['Navigation.getprimary.nav_tools_provisioning'] = 'Service-Warteschlange';
